@@ -1,4 +1,4 @@
-# Copyright (c) 2010 Infrae. All rights reserved.
+# Copyright (c) 2010-2012 Infrae. All rights reserved.
 # See also LICENSE.txt
 # $Id$
 
@@ -9,6 +9,8 @@ from zope.configuration.name import resolve
 from zope.app.locales.extract import POTMaker, POTEntry, py_strings, tal_strings
 from infrae.i18nextract.formulator_extract import formulator_strings
 from infrae.i18nextract.metadata_extract import metadata_strings
+from infrae.i18nextract.utils import load_products
+
 
 class MultiplePOTMaker(POTMaker):
     """This class inserts sets of strings into a POT file.
@@ -32,7 +34,7 @@ class MultiplePOTMaker(POTMaker):
         return '1.0'
 
 
-def extract(packages, output_dir, output_package, domain):
+def extract(packages, output_dir, output_package, domain, products):
     """Extract i18n strings
     """
     parser = OptionParser()
@@ -44,6 +46,9 @@ def extract(packages, output_dir, output_package, domain):
         help="extract to the output package")
     (options, args) = parser.parse_args()
 
+    if products:
+        load_products(products)
+
     output_file = domain + '.pot'
     if options.output_dir:
         if not os.path.exists(options.output_dir):
@@ -82,6 +87,8 @@ def extract(packages, output_dir, output_package, domain):
         maker.add(metadata_strings(path, domain), path, package)
     maker.write()
 
+    return output_file
+
 
 def egg_entry_point(kwargs):
     return extract(**kwargs)
